@@ -70,7 +70,7 @@ class AnalogImpedance(DwfDevice_SubAPI):
 
                 * 0: W1-C1-DUT-C2-R-GND
                 * 1: W1-C1-R-C2-DUT-GND
-                * 8: Impedance Analyzer for the Analog Discovery
+                * 8: |Impedance analyzer:link| for the Analog Discovery
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -89,7 +89,7 @@ class AnalogImpedance(DwfDevice_SubAPI):
 
             * 0: W1-C1-DUT-C2-R-GND
             * 1: W1-C1-R-C2-DUT-GND
-            * 8: Impedance Analyzer for the Analog Discovery
+            * 8: |Impedance analyzer:link| for the Analog Discovery
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
