@@ -1203,7 +1203,7 @@ class AnalogIn(DwfDevice_SubAPI):
             trigger_position (float): The trigger position to be configured, in seconds.
 
         Raises:
-            DwfLibraryError: There was an error while setting the trigger position setpoint.
+            DwfLibraryError: There was an error while setting the trigger position.
         """
         result = self.lib.FDwfAnalogInTriggerPositionSet(self.hdwf, trigger_position)
         if result != RESULT_SUCCESS:
@@ -1216,7 +1216,7 @@ class AnalogIn(DwfDevice_SubAPI):
             float: The currently configured trigger position, in seconds.
 
         Raises:
-            DwfLibraryError: There was an error while getting the trigger position setpoint.
+            DwfLibraryError: There was an error while getting the trigger position.
         """
         c_trigger_position = typespec_ctypes.c_double()
         result = self.lib.FDwfAnalogInTriggerPositionGet(self.hdwf, c_trigger_position)
@@ -1734,13 +1734,13 @@ class AnalogIn(DwfDevice_SubAPI):
         Raises:
             DwfLibraryError: There was an error while getting the trigger length condition info.
         """
-        c_triglen_bitset = typespec_ctypes.c_int()
-        result = self.lib.FDwfAnalogInTriggerLengthConditionInfo(self.hdwf, c_triglen_bitset)
+        c_tlc_bitset = typespec_ctypes.c_int()
+        result = self.lib.FDwfAnalogInTriggerLengthConditionInfo(self.hdwf, c_tlc_bitset)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        triglen_bitset = c_triglen_bitset.value
-        triglen_list = [triglen for triglen in DwfTriggerLengthCondition if triglen_bitset & (1 << triglen.value)]
-        return triglen_list
+        tlc_bitset = c_tlc_bitset.value
+        tlc_list = [tlc for tlc in DwfTriggerLengthCondition if tlc_bitset & (1 << tlc.value)]
+        return tlc_list
 
     def triggerLengthConditionSet(self, trigger_length_condition: DwfTriggerLengthCondition) -> None:
         """Set |AnalogIn| trigger detector length condition.
