@@ -465,45 +465,45 @@ class DigitalIn(DwfDevice_SubAPI):
         fsEdgeFall  = c_fsEdgeFall.value
         return (fsLevelLow, fsLevelHigh, fsEdgeRise, fsEdgeFall)
 
-    def triggerSet(self, fsLevelLow: int, fsLevelHigh: int, fsEdgeRise: int, fsEdgeFall: int) -> None:
+    def triggerSet(self, level_low: int, level_high: int, edge_rise: int, edge_fall: int) -> None:
         """Set trigger."""
         result = self.lib.FDwfDigitalInTriggerSet(
             self.hdwf,
-            fsLevelLow,
-            fsLevelHigh,
-            fsEdgeRise,
-            fsEdgeFall)
+            level_low,
+            level_high,
+            edge_rise,
+            edge_fall)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def triggerGet(self) -> Tuple[int, int, int, int]:
         """Get trigger."""
-        c_fsLevelLow  = typespec_ctypes.c_unsigned_int()
-        c_fsLevelHigh = typespec_ctypes.c_unsigned_int()
-        c_fsEdgeRise  = typespec_ctypes.c_unsigned_int()
-        c_fsEdgeFall  = typespec_ctypes.c_unsigned_int()
+        c_level_low  = typespec_ctypes.c_unsigned_int()
+        c_level_high = typespec_ctypes.c_unsigned_int()
+        c_edge_rise  = typespec_ctypes.c_unsigned_int()
+        c_edge_fall  = typespec_ctypes.c_unsigned_int()
         result = self.lib.FDwfDigitalInTriggerGet(
             self.hdwf,
-            c_fsLevelLow,
-            c_fsLevelHigh,
-            c_fsEdgeRise,
-            c_fsEdgeFall)
+            c_level_low,
+            c_level_high,
+            c_edge_rise,
+            c_edge_fall)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        fsLevelLow  = c_fsLevelLow.value
-        fsLevelHigh = c_fsLevelHigh.value
-        fsEdgeRise  = c_fsEdgeRise.value
-        fsEdgeFall  = c_fsEdgeFall.value
-        return (fsLevelLow, fsLevelHigh, fsEdgeRise, fsEdgeFall)
+        level_low  = c_level_low.value
+        level_high = c_level_high.value
+        edge_rise  = c_edge_rise.value
+        edge_fall  = c_edge_fall.value
+        return (level_low, level_high, edge_rise, edge_fall)
 
-    def triggerResetSet(self, fsLevelLow: int, fsLevelHigh: int, fsEdgeRise: int, fsEdgeFall: int) -> None:
+    def triggerResetSet(self, level_low: int, level_high: int, edge_rise: int, edge_fall: int) -> None:
         """Configure trigger reset settings."""
         result = self.lib.FDwfDigitalInTriggerResetSet(
             self.hdwf,
-            fsLevelLow,
-            fsLevelHigh,
-            fsEdgeRise,
-            fsEdgeFall)
+            level_low,
+            level_high,
+            edge_rise,
+            edge_fall)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
@@ -513,9 +513,9 @@ class DigitalIn(DwfDevice_SubAPI):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def triggerLengthSet(self, trigger_length_min: float, trigger_length_max: float, idxSync: int) -> None:
+    def triggerLengthSet(self, trigger_length_min: float, trigger_length_max: float, index_sync: int) -> None:
         """Set trigger length."""
-        result = self.lib.FDwfDigitalInTriggerLengthSet(self.hdwf, trigger_length_min, trigger_length_max, idxSync)
+        result = self.lib.FDwfDigitalInTriggerLengthSet(self.hdwf, trigger_length_min, trigger_length_max, index_sync)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
